import processing.serial.*;

Serial myPort;  // Create object from Serial class
String val = "";     // Data received from the serial port
float previousval = 0;
float m;
float temp;

PFont verdana;
PFont verdana12;
PFont verdana48;

PImage fondo;  // Background image
PImage termometro; // thermometer image
PImage circulo; // temp variation image

void setup()
{
  printArray(Serial.list()); // print in console the Serial list
  delay(1000);  // And wait one second
  String portName = Serial.list()[5]; //In my case the serial is the n 5
  myPort = new Serial(this, portName, 9600);
  delay(100);

  size(400, 400);
  verdana12 = createFont("Verdana", 12);
  verdana = createFont("Verdana", 32);
  verdana48 = createFont("Verdana", 48);
  textFont(verdana);

  fondo = loadImage("interface_fondo.png");  // load image background
  termometro = loadImage("interface_termometro.png"); // load image thermometer
  circulo = loadImage("interface_circulo.png"); // load image temp variation
}

void draw()
{
  if ( myPort.available() > 0)
  {  // If data is available,
    val = myPort.readStringUntil('\n');         // read it and store it in val
    println(val); //print it out in the console
  } else {
    println("No Data"); //print it out in the console
  }

  temp = float(val); // string to float
  val = nf(temp, 0, 2); // float reduce to 2 decimals to string

  colorMode(RGB);
  background(0);
  image(fondo, 0, 0);
  fill(0);
  textAlign(CENTER);
  textFont(verdana);
  text("Temperature Monitor", width/2, 36);
  textFont(verdana48);
  text(val, width/2, 80);
  textFont(verdana);
  text("ºC", 300, 70);



  fill(0);
  textFont(verdana);
  text( hour() + ":" + minute(), 73, 382); // current time

  stroke(255, 0);
  colorMode(HSB, 360, 100, 100);  // Change mode color to HSB
  m = map(temp, 10, 34, 0, 200);  // Min temp 25ºC to 34º and get the height of rectangle
  float H_color = map(temp, 10, 34, 220, 0);
  // Min temp 25ºC to 34º and get the component H of color (from blue to red)
  fill(H_color, 80, 80); // Fill with current color
  rect(180, 320, 40, -m); // draw rectangle
  circle(202, 342, 52);

  image(termometro, 156, 91);
  image(circulo, 219, 273);
  colorMode(RGB);
  if (previousval > temp) {   // temperature variation
    fill(0, 0, 255);
    text("<", 244, 306);
  } else if (previousval < temp) {
    fill(255, 0, 0);
    text(">", 244, 306);
  } else {
    fill(0);
    text("=", 244, 306);
  }


  previousval=temp; // store previous temperature for compare



  delay(500);
}
